==> prestashop_edition_basic_version_8.0.4.zip: modules/ps_accounts/translations/it.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
global $_MODULE;
$_MODULE = [];
$_MODULE['<{ps_accounts}prestashop>ps_accounts_40047b296fb8a4952e0512c7184e1ca3'] = 'Account PrestaShop';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_9006e8a0d8ca7f627146d32bc9c0eb73'] = 'Associa il tuo negozio al tuo account PrestaShop per attivare e gestire i tuoi abbonamenti nel tuo back office. Non disinstallare questo modulo se hai un abbonamento in corso.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_ceeadaf870d9eaa81cf1fbe32614af64'] = 'Questa azione impedirà immediatamente il funzionamento dei tuoi servizi PrestaShop e di quelli della Community che utilizzano il modulo PrestaShop Accounts per l\'autenticazione.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_01a84505e1f42ba1b80ffed4f9f21221'] = 'Questo negozio è collegato al tuo account PrestaShop. Disconnetti il tuo negozio se non vuoi avere un impatto sulle tue impostazioni live.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_d82864f800210969f401370615e30568'] = 'Alcuni negozi sono collegati al tuo account PrestaShop. La cancellazione di questi negozi avrà un impatto sulle tue impostazioni live.';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_f4f70727dc34561dfde1a3c529b6205c'] = 'Impostazioni';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Assistenza';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_b7ca62f12bc3b8e0d6422c028473a265'] = 'Il tuo account PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_518d650937979216a269cf9830a7b484'] = 'Un solo account per gestire tutti i tuoi negozi PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_655aa4af96bbb20cf78e14b560affb38'] = 'Crea il tuo account PrestaShop o accedi al tuo account esistente';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_d23c41d498fe8587fb2f6ac563426dce'] = 'Collega il tuo negozio al tuo account';
$_MODULE['<{ps_accounts}prestashop>content_23feb5280da1e3a86dc0fcc048f1a58d'] = 'Un\'interfaccia modulare';
$_MODULE['<{ps_accounts}prestashop>content_e661ffe463ad9b9bcea4c49d744058e7'] = 'Gestisci tutta la tua attività in un unico luogo: catalogo prodotti, ordini, pagamenti, consegna e molto altro.';
$_MODULE['<{ps_accounts}prestashop>content_8ea4efcd82809db344ff0d7a76695448'] = 'Tutto l\'essenziale per la tua attività';
$_MODULE['<{ps_accounts}prestashop>content_f27ec0e8d78513e2e60830c62a3a13b8'] = 'Marketing, pagamenti e analisi delle prestazioni: la suite PrestaShop Essentials include tutte le funzionalità necessarie per il successo del tuo negozio.';
$_MODULE['<{ps_accounts}prestashop>content_f2d32f40a4060af2595051d0ab0278cb'] = 'Una soluzione personalizzabile al 100%';
$_MODULE['<{ps_accounts}prestashop>content_9b4e2d0b927094565d6ce673644868a4'] = 'PrestaShop accompagna la tua crescita. Trova i nostri moduli e quelli dei nostri partner sul PrestaShop Addons Marketplace per personalizzare e sviluppare il tuo negozio';
$_MODULE['<{ps_accounts}prestashop>content_1ab1f34b16d32fa54b90ee0f91f39dfd'] = 'Ti diamo il benvenuto.';
$_MODULE['<{ps_accounts}prestashop>content_474684646f833216fdaf79c606af208b'] = 'Accedi al tuo back office per gestire il tuo negozio.';
$_MODULE['<{ps_accounts}prestashop>content_6ed6a381a1de805e2b807f88a95faa2b'] = 'Entra nel back office';
$_MODULE['<{ps_accounts}prestashop>content_8905a5daaa6744846452108776efa036'] = 'Connettiti con un altro metodo';
$_MODULE['<{ps_accounts}prestashop>content_729f27762821b8ec88f1a656be7dff72'] = 'È necessario attivare il proprio account facendo clic sul link contenuto nell\'e-mail. Se hai bisogno di ricevere un nuovo link di attivazione,[1]clicca qui[/1].';
$_MODULE['<{ps_accounts}prestashop>content_476ff05d1175f9a35d268828caf300f2'] = 'Si è verificato un errore durante il login, contatta l\'assistenza PrestaShop';
$_MODULE['<{ps_accounts}prestashop>content_fd359ea79740b865e45c2bf6fe5d3ab1'] = 'Non è possibile accedere al back office con questo account. Prova con un altro account o contatta l\'amministratore.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_e53a9fbe0e31ac65b72e5e2c876074d8'] = 'Gestire l\'account PrestaShop';

==> prestashop_edition_basic_version_8.2.0.zip: modules/ps_accounts/translations/it.php <==
<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License version 3.0
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License version 3.0
 */
global $_MODULE;
$_MODULE = [];
$_MODULE['<{ps_accounts}prestashop>ps_accounts_40047b296fb8a4952e0512c7184e1ca3'] = 'Account PrestaShop';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_248ed4a0f71472c36d19bb0f1bcb68a0'] = 'Collegate il vostro negozio al vostro account PrestaShop per attivare e gestire gli abbonamenti nel vostro back office. Non disinstallate questo modulo se avete un abbonamento in corso.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_ceeadaf870d9eaa81cf1fbe32614af64'] = 'Questa azione impedirà immediatamente il funzionamento dei tuoi servizi PrestaShop e di quelli della Community che utilizzano il modulo PrestaShop Accounts per l\'autenticazione.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_01a84505e1f42ba1b80ffed4f9f21221'] = 'Questo negozio è collegato al tuo account PrestaShop. Disconnetti il tuo negozio se non vuoi avere un impatto sulle tue impostazioni live.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_d82864f800210969f401370615e30568'] = 'Alcuni negozi sono collegati al tuo account PrestaShop. La cancellazione di questi negozi avrà un impatto sulle tue impostazioni live.';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_f4f70727dc34561dfde1a3c529b6205c'] = 'Impostazioni';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_6a26f548831e6a8c26bfbbd9f6ec61e0'] = 'Assistenza';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_b7ca62f12bc3b8e0d6422c028473a265'] = 'Il tuo account PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_53c4c7fe12fffd658daacfa5b41eb495'] = 'Un unico account per gestire tutti i vostri negozi PrestaShop';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_655aa4af96bbb20cf78e14b560affb38'] = 'Crea il tuo account PrestaShop o accedi al tuo account esistente';
$_MODULE['<{ps_accounts}prestashop>settingstranslations_a60d78ec73c0c133ce16b10419a3fdf6'] = 'Collegate il vostro negozio al vostro account';
$_MODULE['<{ps_accounts}prestashop>content_23feb5280da1e3a86dc0fcc048f1a58d'] = 'Un\'interfaccia modulare';
$_MODULE['<{ps_accounts}prestashop>content_e661ffe463ad9b9bcea4c49d744058e7'] = 'Gestisci tutta la tua attività in un unico luogo: catalogo prodotti, ordini, pagamenti, consegna e molto altro.';
$_MODULE['<{ps_accounts}prestashop>content_8ea4efcd82809db344ff0d7a76695448'] = 'Tutto l\'essenziale per la tua attività';
$_MODULE['<{ps_accounts}prestashop>content_f27ec0e8d78513e2e60830c62a3a13b8'] = 'Marketing, pagamenti e analisi delle prestazioni: la suite PrestaShop Essentials include tutte le funzionalità necessarie per il successo del tuo negozio.';
$_MODULE['<{ps_accounts}prestashop>content_f2d32f40a4060af2595051d0ab0278cb'] = 'Una soluzione personalizzabile al 100%';
$_MODULE['<{ps_accounts}prestashop>content_9b4e2d0b927094565d6ce673644868a4'] = 'PrestaShop accompagna la tua crescita. Trova i nostri moduli e quelli dei nostri partner sul PrestaShop Addons Marketplace per personalizzare e sviluppare il tuo negozio';
$_MODULE['<{ps_accounts}prestashop>content_1ab1f34b16d32fa54b90ee0f91f39dfd'] = 'Ti diamo il benvenuto.';
$_MODULE['<{ps_accounts}prestashop>content_474684646f833216fdaf79c606af208b'] = 'Accedi al tuo back office per gestire il tuo negozio.';
$_MODULE['<{ps_accounts}prestashop>content_6ed6a381a1de805e2b807f88a95faa2b'] = 'Entra nel back office';
$_MODULE['<{ps_accounts}prestashop>content_8905a5daaa6744846452108776efa036'] = 'Connettiti con un altro metodo';
$_MODULE['<{ps_accounts}prestashop>content_729f27762821b8ec88f1a656be7dff72'] = 'È necessario attivare il proprio account facendo clic sul link contenuto nell\'e-mail. Se hai bisogno di ricevere un nuovo link di attivazione,[1]clicca qui[/1].';
$_MODULE['<{ps_accounts}prestashop>content_476ff05d1175f9a35d268828caf300f2'] = 'Si è verificato un errore durante il login, contatta l\'assistenza PrestaShop';
$_MODULE['<{ps_accounts}prestashop>content_fd359ea79740b865e45c2bf6fe5d3ab1'] = 'Non è possibile accedere al back office con questo account. Prova con un altro account o contatta l\'amministratore.';
$_MODULE['<{ps_accounts}prestashop>ps_accounts_e53a9fbe0e31ac65b72e5e2c876074d8'] = 'Gestire l\'account PrestaShop';
